@@ -1,5 +1,4 @@
 /*
-  
   -----------------------------[ XCF Loader ]-----------------------------
 
   This program is free software; you can redistribute it and/or modify
@@ -15,21 +14,15 @@
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software Foundation,
   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-
 */
+#include <stdint.h>
+#include <stdlib.h>
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
-#include <stdio.h>
-#include <math.h>
-#include <netinet/in.h>
-
-#include "common.h"
-#include "image.h"
 #include "loader_xcf.h"
 
+#define MIN(a, b) (((a) < (b)) ? (a) : (b))
+#define MAX(a, b) (((a) > (b)) ? (a) : (b))
+
 #ifndef WORDS_BIGENDIAN
 
 #define A_VAL(p) ((uint8_t *)(p))[3]
